@@ -23,6 +23,7 @@ logger = logging.getLogger(__name__)
 
 
 @click.group()
+@click.version_option(version=__version__)
 @click.option('--name', '-n', default='reV_collect', type=str,
               show_default=True,
               help='Collection job name. Default is "reV_collect".')
@@ -36,14 +37,6 @@ def main(ctx, name, verbose):
     ctx.obj['VERBOSE'] = verbose
 
 
-@main.command()
-def version():
-    """
-    print version
-    """
-    click.echo(__version__)
-
-
 @main.command()
 def valid_config_keys():
     """
